# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage restore imaging

Revision ID: 4cb741e8606a
Revises: adb4a976c9f8
Create Date: 2021-10-08 15:26:45.136710

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "4cb741e8606a"
down_revision = "adb4a976c9f8"
branch_labels = None
depends_on = None


dag_content = """JOB FETCH std_restore_imaging_fetch.condor
VARS FETCH jobname="$(JOB)"

JOB ENVOY std_restore_imaging_envoy.condor
VARS ENVOY jobname="$(JOB)"

JOB DELIVER std_restore_imaging_deliver.condor
VARS DELIVER jobname="$(JOB)"

PARENT FETCH CHILD ENVOY
PARENT ENVOY CHILD DELIVER
"""

fetch_content = """executable = std_restore_imaging_fetch.sh
arguments = {{product_locator}} {{cal_locator}}

output = restore_img_fetch.out
error = restore_img_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""

envoy_content = """executable = std_restore_imaging_envoy.sh
arguments = metadata.json PPR.xml

output = restore_img_envoy.out
error = restore_img_envoy.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, ./working, ./rawdata, ./products{{#remote}}, {{profile}}.properties{{/remote}}, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True

{{^remote}}
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True
{{/remote}}
{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue
"""

deliver_content = """executable = std_restore_imaging_deliver.sh
arguments = {{request_id}}

output = restore_img_deliver.out
error = restore_img_deliver.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/deliver, ./products
transfer_output_files = delivery.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue
"""


old_content = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore-img.out
error = restore-img.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json{{files_to_transfer}}
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue
"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_restore_imaging.condor'
        """
    )

    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging.dag', E'{dag_content}', 'std_restore_imaging')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_fetch.condor', E'{fetch_content}', 'std_restore_imaging')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_envoy.condor', E'{envoy_content}', 'std_restore_imaging')
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging_deliver.condor', E'{deliver_content}', 'std_restore_imaging')
            """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('std_restore_imaging_%.condor')
        AND workflow_name = 'std_restore_imaging'
        """
    )

    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name)
            VALUES ('std_restore_imaging.condor', E'{old_content}', 'std_restore_imaging')
            """
    )
